@@ -3,7 +3,6 @@ from __future__ import with_statement
 from contextlib import contextmanager
 from operator import attrgetter
 from gettext import gettext as _
-import imp
 import inspect
 import os
 import sys
@@ -18,6 +17,20 @@ import signal
 import threading
 import plac_core
 
+version = sys.version_info[:2]
+
+if version < (3, 5):
+    from imp import load_source
+else:
+    import importlib.util
+
+    def load_source(dotname, path):
+        spec = importlib.util.spec_from_file_location(dotname, path)
+        mod = importlib.util.module_from_spec(spec)
+        spec.loader.exec_module(mod)
+        return mod
+
+
 if sys.version < '3':
     def exec_(_code_, _globs_=None, _locs_=None):
         if _globs_ is None:
@@ -53,6 +66,11 @@ else:
             raise exc.with_traceback(tb)
         raise exc
 
+try:
+    raw_input
+except NameError:  # Python 3
+    raw_input = input
+
 
 def decode(val):
     """
@@ -63,7 +81,7 @@ def decode(val):
         return val.decode('utf-8')
     except AttributeError:
         # it was an already decoded unicode object
-        return val
+        return str(val)
 
 # ############################ generic utils ############################### #
 
@@ -107,6 +125,7 @@ def less(text):
     po.stdin.close()
     po.wait()
 
+
 use_less = (sys.platform != 'win32')  # unices
 
 
@@ -313,7 +332,7 @@ def partial_call(factory, arglist):
 
 def import_main(path, *args):
     """
-    An utility to import the main function of a plac tool. It also
+    A utility to import the main function of a plac tool. It also
     works with command container factories.
     """
     if ':' in path:  # importing a factory
@@ -330,7 +349,7 @@ def import_main(path, *args):
     else:
         fullpath = path
     name, ext = os.path.splitext(os.path.basename(fullpath))
-    module = imp.load_module(name, open(fullpath), fullpath, (ext, 'U', 1))
+    module = load_source(name, fullpath)
     if factory_name:
         tool = partial_call(getattr(module, factory_name), args)
     else:
@@ -390,7 +409,7 @@ class BaseTask(object):
         except (GeneratorExit, TerminatedProcess, KeyboardInterrupt):
             # soft termination
             self.status = 'KILLED'
-        except:  # unexpected exception
+        except Exception:  # unexpected exception
             self.etype, self.exc, tb = sys.exc_info()
             self.tb = ''.join(traceback.format_tb(tb)) if stringify_tb else tb
             self.status = 'ABORTED'
@@ -810,7 +829,7 @@ class _AsynHandler(asynchat.async_chat):
         if data.endswith('\n') and not data.endswith(self.terminator):
             data = data[:-1] + self.terminator  # fix newlines
         self.push(data)
-    
+
     def collect_incoming_data(self, data):
         "Collect one character at the time"
         self.data.append(data)
@@ -1064,7 +1083,7 @@ class Interpreter(object):
                 pass
 
     def interact(self, stdin=sys.stdin, prompt='i> ', verbose=False):
-        "Starts an interactive command loop reading commands from the consolle"
+        "Starts an interactive command loop reading commands from the console"
         try:
             import readline
             readline_present = True
